securitysettings/eapqtdialogs/inc/eapfastprovnotsuccessnotedialog.h
changeset 42 53085837e73a
parent 39 fe6b6762fccd
--- a/securitysettings/eapqtdialogs/inc/eapfastprovnotsuccessnotedialog.h	Tue Jul 06 14:18:35 2010 +0300
+++ b/securitysettings/eapqtdialogs/inc/eapfastprovnotsuccessnotedialog.h	Wed Aug 18 09:50:56 2010 +0300
@@ -11,23 +11,39 @@
 *
 * Contributors:
 *
 * Description: Fast Provisioning not successfull note Dialog
 *
 */
 
 /*
-* %version: 3 %
+* %version: 4 %
 */
 
 #ifndef __EAPFASTPROVNOTSUCCESSNOTEDIALOG_H__
 #define __EAPFASTPROVNOTSUCCESSNOTEDIALOG_H__
 
+// System includes
 #include <HbMessageBox>
 #include <hbdevicedialoginterface.h>
 
+// User includes
+
+// Forward declarations
 class HbAction;
 class HbTranslator;
 
+// External data types
+
+// Constants
+
+/*!
+   @addtogroup group_eap_fast_prov_not_success_note_dialog
+   @{
+ */
+
+// Class declaration
+
 class EapFastProvNotSuccessNoteDialog: public HbMessageBox, public HbDeviceDialogInterface
     {
     Q_OBJECT
@@ -39,20 +55,21 @@
         ~EapFastProvNotSuccessNoteDialog();
         
         /* Function creates the actual dialog widget */
-        void createDialog(const QVariantMap &parameters );
+        void createDialog();
         
         /* Device dialog parameters to be set while dialog is displayed.
-         * Not supported.
+         * Not supported. (from HbDeviceDialogInterface)
          */
         bool setDeviceDialogParameters(const QVariantMap &parameters);
         
-        /* Not supported */
+        /* Not supported. (from HbDeviceDialogInterface) */
         int deviceDialogError() const;
         
         /* Closes the device dialog */
         void closeDeviceDialog(bool byClient);
         
-        /* Returns a pointer to this dialog widget */
+        /* Returns a pointer to this dialog widget.
+           (from HbDeviceDialogInterface) */
         HbPopup *deviceDialogWidget() const;
                 
     signals:
@@ -73,13 +90,17 @@
                 
         Q_DISABLE_COPY(EapFastProvNotSuccessNoteDialog)
    
-    private:
+    private: // data
+        // NOT OWNED
         
-        /* Pointer to the HbTranslator */
+        // OWNED   
+        //! Pointer to the HbTranslator
         QScopedPointer<HbTranslator> mTranslator;
                 
-        /* Tells whether Ok Action has already been pressed */
+        //! Tells whether Ok Action has already been pressed
         bool mOkActionPressed;
     };
 
+/*! @} */
+
 #endif // __EAPFASTPROVNOTSUCCESSNOTEDIALOG_H__
@@ -11,23 +11,39 @@
 * Contributors:
 *
-* Description: Fast Provisioning not successfull note Dialog
+* Description: 
+*   EAP-FAST Provisioning not successfull note Dialog
 *
 */
@@ -39,20 +55,21 @@
         int deviceDialogError() const;
         
-        /* Closes the device dialog */
+        /* Closes the device dialog. (from HbDeviceDialogInterface) */
         void closeDeviceDialog(bool byClient);
         